@@ -33,6 +33,9 @@ def find_forks(repo_url: str):
     print(df.ever_changed.value_counts())
     return df
 
+def fork_status(repo_url: str):
+    cmd = 'for branch in `git branch -r | grep -v HEAD`;do echo -e `git show --format="%ci %cr" $branch | head -n 1` \\t$branch; done | sort -r\n'
+    os.system(cmd)
 
 def find_contributors(repo_url: str):
     from .sshconf import SshConfig
