@@ -15,6 +15,7 @@ except OSError:
     term_wdith = 80
 
 pd.set_option('display.max_colwidth',term_wdith - 20)
+pd.set_option('display.max_rows', None)
 
 # TODO: treat 'cd' in a special way s.t. we can generate the absolute path wherever possible
 FILTER_TERMS = ['ls','install','dt hist', 'git ', 'dt ', 'code',
@@ -60,14 +61,9 @@ def hist_tail(n_lines=20, excluded_terms = []):
     # checks that we can find 
     zsh_hist = f"{os.path.expanduser('~')}/.{shell}_history"
     if not os.path.exists(zsh_hist):
-        # dumb hack for bashrc
-        # zsh_hist = f"{os.path.expanduser('~')}/.{shell}rc"
-        # if not.path.exists(zsh_hist): raise NotImplementedError('Not sure where to look')
-    # else:
         raise NotImplementedError('Not sure where to look')
     split_f = str(sp.check_output(['tail',zsh_hist,'-n',str(n_lines * 3)])).split(':')
 
-    # TODO: \n -> \\n for Mac, check if this is an issue on Linux
     # Work Ubuntu 20.04 so far so good
     # TODO: fix this horrible line 
     parsed_commands = [ ''.join(l.replace('\\n','').strip().split(';')[-1:]) for l in split_f if '\\n' in l]
@@ -107,7 +103,8 @@ def hist_save(lines_to_save: list, snippet_name: str, n_lines: str):
 
     # prepare the correct saving format
     saved_time = dt.datetime.now().strftime('%Y-%m-%d %H-%M-%S')
-    parsed_lines = [df.iloc[x].Command for x in lines_to_save]
+    # TODO: figure out why there's this horrible off by-one error
+    parsed_lines = [df.iloc[x-1].Command for x in lines_to_save]
     saved_lines = [snippet_name, saved_time, parsed_lines]
     
     config['snippets'].append(saved_lines)
