@@ -102,6 +102,24 @@ KNOWN_PARAMS = (
 
 known_params = [x.lower() for x in KNOWN_PARAMS]  # pylint: disable=invalid-name
 
+def print_ls(ssh_config):
+    """
+    Prints the ssh config in a human readable format.
+    """
+    import pandas as pd
+
+    host = []
+
+    for i in range(len(ssh_config.lines_))[::4]:
+        host_name = ssh_config.lines_[i].value
+        ip_address = ssh_config.lines_[i + 1].value
+        user = ssh_config.lines_[i + 2].value
+
+        host.append([host_name, ip_address, user])
+
+    df = pd.DataFrame(host, columns=["host", "ip", "user"])
+    print(df)
+
 class ConfigLine:  # pylint: disable=too-few-public-methods
     """ Holds configuration for a line in ssh config """
     def __init__(self, line, host=None, key=None, value=None):
